# Alfi: Approximate Latent Force Inference

> _Don't miss out!_

[![Latest PyPI Version][pb]][pypi] [![PyPI Downloads][db]][pypi] [![Documentation Status](https://readthedocs.org/projects/lafomo/badge/?version=latest)](https://lafomo.readthedocs.io/en/latest/?badge=latest)


[pb]: https://img.shields.io/pypi/v/lafomo.svg
[pypi]: https://pypi.org/project/lafomo/

[db]: https://img.shields.io/pypi/dm/lafomo?label=pypi%20downloads


### Implement Latent Force Models in under 10 lines of code!

This library implements several Latent Force Models. These are all implemented in building blocks simplifying the creation of novel models or combinations.

We support analytical (exact) inference in addition to inducing point approximations for non-linear LFMs written in PyTorch.


## Installation

`pip install alfi`

## Documentation


See Jupyter notebooks in the documentation [here](https://alfi.readthedocs.io/en/latest/notebooks_list.html). Alternatively, directly browse the notebooks in the `docs/notebooks/` directory. The docs contain linear, non-linear (both variational and MCMC methods), and partial Latent Force Models. The notebooks also contain complete examples from the literature such as a replication of the analytical linear Latent Force Model from [Lawrence et al., 2006](https://papers.nips.cc/paper/3119-modelling-transcriptional-regulation-using-gaussian-processes.pdf)



